package com.zd.laboratory.service;

import java.util.List;
import com.zd.laboratory.domain.ApkMachineconfig;

/**
 * 【请填写功能名称】Service接口
 *
 * @author zd
 * @date 2021-12-09
 */
public interface IApkMachineconfigService
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public ApkMachineconfig selectApkMachineconfigById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param apkMachineconfig 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<ApkMachineconfig> selectApkMachineconfigList(ApkMachineconfig apkMachineconfig);

    /**
     * 新增【请填写功能名称】
     *
     * @param apkMachineconfig 【请填写功能名称】
     * @return 结果
     */
    public int insertApkMachineconfig(ApkMachineconfig apkMachineconfig);

    /**
     * 修改【请填写功能名称】
     *
     * @param apkMachineconfig 【请填写功能名称】
     * @return 结果
     */
    public int updateApkMachineconfig(ApkMachineconfig apkMachineconfig);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteApkMachineconfigByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteApkMachineconfigById(Long id);


    /**
     * 查询【请填写功能名称】
     *
     * @param hardwareNum 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public ApkMachineconfig selectApkMachineconfigByHardwareNum(String hardwareNum);
}
